==> 1.7.8&file=out_yasapi-1.7.8-src.tar.gz: out_yasapi-1.7.8/out_yasapi/yasapi_disconnect.c <==
/*
 * yasapi_disconnect.c
 * Copyright (C) 2015-2016 Peter Belkner <pbelkner@snafu.de>
 *
 * This file is part of out_yasapi.
 *
 * out_yasapi is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * out_yasapi is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with out_yasapi.  If not, see <http://www.gnu.org/licenses/>.
 */
#include <yasapi.h>

///////////////////////////////////////////////////////////////////////////////
static void DisconnectAllDisconnect(Player *pPlayer, int bReset)
{
  IAudioClient *pClient=pPlayer->connect.pClient;
  HRESULT hr;

  if (pClient&&bReset&&!pPlayer->connect.bInvalid) {
    TimeFlush(&pPlayer->time);
    hr=pClient->lpVtbl->Reset(pClient);

    if (FAILED(hr)) {
      DERROR(AUDCLNT_E_NOT_INITIALIZED,hr);
      DERROR(AUDCLNT_E_NOT_STOPPED,hr);
      DERROR(AUDCLNT_E_BUFFER_OPERATION_PENDING,hr);
      DERROR(AUDCLNT_E_SERVICE_NOT_RUNNING,hr);
      DUNKNOWN(hr);
      DPRINTF(0,"  Warning: re-setting audio client failed.\n");
    }
    else
      DPRINTF(0,"  audio client reset.\n");
  }

  PlayerDisconnect(pPlayer);
}

///////////////////////////////////////////////////////////////////////////////
static void DisconnectNoDisconnect(Player *pPlayer, int bReset)
{
}

static int DisconnectNoReconnect(Player *pPlayer)
{
  return 0;
}

const Disconnect gcDisconnectNo={
  DisconnectNoDisconnect,
  DisconnectNoReconnect,
  DisconnectAllDisconnect,
};

///////////////////////////////////////////////////////////////////////////////
static int DisconnectYesReconnect(Player *pPlayer)
{
  return PlayerConnect(pPlayer,0,0);
}

const Disconnect gcDisconnectYes={
  DisconnectAllDisconnect,
  DisconnectYesReconnect,
  DisconnectAllDisconnect,
};

==> 1.7.12&file=out_yasapi-1.7.12-src.tar.gz: out_yasapi-1.7.12/out_yasapi/yasapi_disconnect.c <==
/*
 * yasapi_disconnect.c
 * Copyright (C) 2015-2016 Peter Belkner <pbelkner@snafu.de>
 *
 * This file is part of out_yasapi.
 *
 * out_yasapi is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * out_yasapi is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with out_yasapi.  If not, see <http://www.gnu.org/licenses/>.
 */
#include <yasapi.h>

///////////////////////////////////////////////////////////////////////////////
static void DisconnectAllDisconnect(Player *pPlayer, int bReset)
{
  IAudioClient *pClient=pPlayer->connect.pClient;
  HRESULT hr;

  if (pClient&&bReset&&!ConnectionIsInvalid(&pPlayer->connect)) {
    TimeFlush(&pPlayer->time);
    hr=pClient->lpVtbl->Reset(pClient);

    if (FAILED(hr)) {
      DERROR(AUDCLNT_E_NOT_INITIALIZED,hr);
      DERROR(AUDCLNT_E_NOT_STOPPED,hr);
      DERROR(AUDCLNT_E_BUFFER_OPERATION_PENDING,hr);
      DERROR(AUDCLNT_E_SERVICE_NOT_RUNNING,hr);
      DUNKNOWN(hr);
      DPRINTF(0,"  Warning: re-setting audio client failed.\n");
    }
    else
      DPRINTF(0,"  audio client reset\n");
  }

  PlayerDisconnect(pPlayer);
}

///////////////////////////////////////////////////////////////////////////////
static void DisconnectNoDisconnect(Player *pPlayer, int bReset)
{
}

static int DisconnectNoReconnect(Player *pPlayer)
{
  if (pPlayer->state<PLAYER_STATE_READY)
    pPlayer->state=PLAYER_STATE_READY;

  return 0;
}

const Disconnect gcDisconnectNo={
  DisconnectNoDisconnect,
  DisconnectNoReconnect,
  DisconnectAllDisconnect,
};

///////////////////////////////////////////////////////////////////////////////
static int DisconnectYesReconnect(Player *pPlayer)
{
  return PlayerConnect(pPlayer,0,0);
}

const Disconnect gcDisconnectYes={
  DisconnectAllDisconnect,
  DisconnectYesReconnect,
  DisconnectAllDisconnect,
};
